/*  liblipsevent - Library of LiPS event model
 * evt_type.h - 
 *
 * Authors: ZHAO Liangjing <liangjing.zhao@orange-ftgroup.com> 
 * 
 * This software and associated documentation files (the "Software") 
 * are copyright (C) 2005 LiPS Linux Phone Standards Forum [FranceTelecom] 
 * All Rights Reserved. 
 *
 * A copyright license is hereby granted for redistribution and use of 
 * the Software in source and binary forms, with or without modification, 
 * provided that the following conditions are met: 
 * - Redistributions of source code must retain the above copyright notice, 
 * this copyright license and the following disclaimer. 
 * - Redistributions in binary form must reproduce the above copyright 
 * notice, this copyright license and the following disclaimer in the 
 * documentation and/or other materials provided with the distribution. 
 * - Neither the name of LiPS  nor the names of its Members may be used 
 * to endorse or promote products derived from the Software without 
 * specific prior written permission. 
 *
 * A patent license for any Necessary Claims owned by Members of LiPS Forum 
 * to make, have made, use, import, offer to sell, lease and sell or otherwise 
 * distribute any implementation compliant with the any specification adopted 
 * by the LiPS Forumcan be obtained from the respective Members on reasonable 
 * and non-discriminatory terms and conditions and under reciprocity, as 
 * regulated in more detail in the Internal Policy of the LiPS Forum. 
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER, ITS MEMBERS AND CONTRIBUTORS 
 * "AS IS", AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE 
 * AND NON-INFRINGEMENT ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER, 
 * ITS MEMBERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; 
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE. 
 */

/* !
 *@file <evt_type.h>
 *
 *@brief Public header file for the Event related type definition.
 *@author ZHAO Liangjing
 *
 *****************************************************************************/

#ifndef LIPS_EVT_TYPE_H_
#define LIPS_EVT_TYPE_H_

#ifdef __cplusplus
extern "C"
{
#endif                          /* __cplusplus */

  /******************************************************************************
   * Includes
   *****************************************************************************/
#include <stdint.h>

  /******************************************************************************
   * Type definition
   *****************************************************************************/
#ifndef TRUE
#define TRUE 1
#endif

#ifndef FALSE
#define FALSE 0
#endif

#ifndef NULL
#define NULL 0
#endif

  /* ! @var typedef uint32_t sid_t;
     @brief session identifier type

     No additional information.
   */
  typedef uint32_t sid_t;

  /* ! @var typedef uint32_t rid_t;
     @brief request identifier type;

     No additional information.
   */
  typedef uint32_t rid_t;

  typedef enum
  {
    EVT_ERROR_NONE = 0,         ///< No error.
    EVT_ERROR_GENERAL = -6900,  ///< Error no specified.
    EVT_ERROR_NULL,             ///< Pointer is NULL.
    EVT_ERROR_NOSUPPORT,        ///< Operation isn't supported.
    EVT_ERROR_TIMEOUT,          ///< Time out
    EVT_ERROR_MEM,              ///< No enough memory.
    EVT_ERROR_WRONG_SID,        ///< No such session id.
    EVT_ERROR_WRONG_RID,        ///< No such request id.
    EVT_ERROR_EVT_PENDING,      ///< Event is pending.
    EVT_ERROR_EVT_COMPLETE,     ///< Event has been already delivered to the client but the client has not released yet.
    EVT_ERROR_NO_SUCH_EVT,      ///< No such registered type for unsolicited event or no such registered rid for asynchronous event.
    EVT_ERROR_CALLBACK,         ///< Callback function pointer is wrong.
    EVT_ERROR_NO_PENDING_EVT,   ///< No pending event.
    EVT_ERROR_DUPLICATED_REG    ///< Duplicated register.
  } _evt_err_t;

  typedef enum
  {
    EVT_STATE_NOTIFY,           ///< To Notify the app.
    EVT_STATE_COMPLIETED,       ///< Request was completed.
    EVT_STATE_CANCELED          ///< Request was canceled.
  } _req_state_t;

#ifdef __cplusplus
}
#endif                          /* __cplusplus */

#ifndef __cplusplus
#ifndef _BOOL_
#define _BOOL_ 1
typedef enum
{ false = FALSE, true = TRUE } bool;
#endif
#endif

#endif // LIPS_EVT_TYPE_H_

